sphinx-click
============

``sphinx-click`` is a `Sphinx`__ plugin that allows you to automatically
extract documentation from a `click-based`__ application and include it in
your docs.

__ http://www.sphinx-doc.org/
__ http://click.pocoo.org/

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing
   changelog
   examples/index

.. seealso::

    Module ``click``
      This extension assumes you are using ``click`` to create your command
      line application.

    Module ``sphinxcontrib.autoprogram``
      An equivalent library for use with ``argparse``.
